==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/midi/src/MIDI_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>Configurar el Plugin MIDI</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>Canal MIDI</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Mensaje Init</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Salidas</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Este provee soporte de Entrada/Salida para dispositivos MIDI.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Soporte de Salida no disponible.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Abierto</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>No Abierto</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Salida inválida</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Soporte de Entrada no disponible.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Entrada inválida</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="196"/>
        <source>No error occurred.</source>
        <translation>No se produjo ningún error.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="198"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Se produjo un error al leer desde el archivo.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="200"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Se produjo un error al escribir al archivo.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="202"/>
        <source>A fatal error occurred.</source>
        <translation>Se produjo un error fatal.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="204"/>
        <source>Resource error occurred.</source>
        <translation>Se produjo un error de recursos.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="206"/>
        <source>The file could not be opened.</source>
        <translation>El archivo no pudo ser abierto.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="208"/>
        <source>The operation was aborted.</source>
        <translation>Se abortó la operación.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="210"/>
        <source>A timeout occurred.</source>
        <translation>Se ha producido un tiempo de espera.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="212"/>
        <source>An unspecified error occurred.</source>
        <translation>Se ha producido un error no especificado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="214"/>
        <source>The file could not be removed.</source>
        <translation>El archivo no pudo ser eliminado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="216"/>
        <source>The file could not be renamed.</source>
        <translation>El archivo no pudo ser renombrado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="218"/>
        <source>The position in the file could not be changed.</source>
        <translation>La posición en el archivo no pudo ser cambiado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="220"/>
        <source>The file could not be resized.</source>
        <translation>No se pudo cambiar el tamaño del archivo.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="222"/>
        <source>The file could not be accessed.</source>
        <translation>No se puede acceder al archivo.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="224"/>
        <source>The file could not be copied.</source>
        <translation>El archivo no puede ser copiado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="226"/>
        <source>An unknown error occurred.</source>
        <translation>Se ha producido un error desconocido.</translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.7.orig.tar.xz: qlcplus-QLC-_4.12.7/plugins/midi/src/MIDI_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>Configurar el Plugin MIDI</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>Canal MIDI</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Mensaje Init</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Salidas</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Este provee soporte de Entrada/Salida para dispositivos MIDI.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Soporte de Salida no disponible.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Abierto</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>No Abierto</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Salida inválida</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Soporte de Entrada no disponible.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Entrada inválida</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="112"/>
        <source>No error occurred.</source>
        <translation>No se produjo ningún error.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="114"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Se produjo un error al leer desde el archivo.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="116"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Se produjo un error al escribir al archivo.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="118"/>
        <source>A fatal error occurred.</source>
        <translation>Se produjo un error fatal.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="120"/>
        <source>Resource error occurred.</source>
        <translation>Se produjo un error de recursos.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="122"/>
        <source>The file could not be opened.</source>
        <translation>El archivo no pudo ser abierto.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="124"/>
        <source>The operation was aborted.</source>
        <translation>Se abortó la operación.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="126"/>
        <source>A timeout occurred.</source>
        <translation>Se ha producido un tiempo de espera.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="128"/>
        <source>An unspecified error occurred.</source>
        <translation>Se ha producido un error no especificado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="130"/>
        <source>The file could not be removed.</source>
        <translation>El archivo no pudo ser eliminado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="132"/>
        <source>The file could not be renamed.</source>
        <translation>El archivo no pudo ser renombrado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="134"/>
        <source>The position in the file could not be changed.</source>
        <translation>La posición en el archivo no pudo ser cambiado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="136"/>
        <source>The file could not be resized.</source>
        <translation>No se pudo cambiar el tamaño del archivo.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="138"/>
        <source>The file could not be accessed.</source>
        <translation>No se puede acceder al archivo.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="140"/>
        <source>The file could not be copied.</source>
        <translation>El archivo no puede ser copiado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="142"/>
        <source>An unknown error occurred.</source>
        <translation>Se ha producido un error desconocido.</translation>
    </message>
</context>
</TS>
